function PrintDescriptivesUnivariate(DataMCA,J,detailed);
%prints the descriptives in the 'output' generated by CAnalysis.m
%
% INPUT
%       output      The 'output' structure generated by CAnalysis.m
%       detailed    1 -> Prints all the details
%                   0 -> Prints the basic information
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Crosstabulation matrix
disp(' ');
me.str=sprintf('Number of variables  : %.0f ',DataMCA.Q);disp(me.str);
me.str=sprintf('Number of categories : %.0f ',J);disp(me.str);
if DataMCA.supplementary>0,
   me.str=sprintf('Number of supplementary variables   : %.0f ',DataMCA.supplementary);disp(me.str);
   [tmp1,tmp2]=size(DataMCA.labels_sup);
   me.str=sprintf('Number of supplementary categories  : %.0f ',tmp1);disp(me.str);
end;

if isempty(DataMCA.X) == 0,
    if detailed == 1,
        
        %Find the maximum frequence (improved in MCA 5.02; 10/02/2015)
        maxf=0;
        [tmp1,tmp2]=size(DataMCA.X);
        for i=1:tmp2,
            table=tabulate(DataMCA.X(:,i));
            tmp1 = max(table(:,2));
            if maxf < tmp1,
                maxf=tmp1;
            end;
        end;
        if DataMCA.supplementary>0,
            [tmp1,tmp2]=size(DataMCA.Xsup);
            for i=1:tmp2,
                table=tabulate(DataMCA.Xsup(:,i));
                tmp1 = max(table(:,2));
                if maxf < tmp1,
                    maxf=tmp1;
                end;
            end;
        end;
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
        buff = sprintf('\n\nUnivariate descriptive statistics of variables\n');disp(buff);
        tmp3=1; 
        for i=1:DataMCA.Q,
            tmp4=DataMCA.M(1,i)+ tmp3 -1;
            buff = sprintf('Variable: %.0f',i);disp(buff);
            bartext( DataMCA.X(:,i),DataMCA.labels(tmp3:tmp4),maxf);
            tmp3 = tmp4+1;
        end;
        if DataMCA.supplementary>0,
            buff = sprintf('\nUnivariate descriptive statistics of supplementary variables\n');disp(buff);
            tmp3=1; 
            for i=1:DataMCA.supplementary,
                tmp4=DataMCA.Msup(1,i)+ tmp3 -1;
                buff = sprintf('Supplementary variable: %.0f',i);disp(buff);
                bartext( DataMCA.Xsup(:,i),DataMCA.labels_sup(tmp3:tmp4),maxf);
                 tmp3 = tmp4+1;
            end;
        end;
    end;
end;
% 
% %Crosstabulation matrix
% disp(' ');
% me.str=sprintf('The %.0f x %.0f crosstabulation table',output.I,output.J);
% disp(me.str);
% disp(' ');
% CrossTabulateLabels(output.N, output.labels.r, output.labels.c);
% disp(' ');
% disp(' ');
% 
% if isfield(output,'SupRow'),
% 	disp('Crosstabulation table related to supplementary columns');
% 	disp(' ');
% 	CrossTabulateLabels(output.SupRow, output.labels.sr, output.labels.c);
% 	disp(' ');
% 	disp(' ');       
% end;
% 
% if isfield(output,'SupCol'),
% 	disp('Crosstabulation table related to supplementary columns');
% 	disp(' ');
% 	CrossTabulateLabels(output.SupCol, output.labels.r, output.labels.sc);
% 	disp(' ');
% 	disp(' ');       
% end;
% 
% if detailed == 1,
%    %Row and columns sums & masses
%    disp('-------------------------------------------------------------------------');
%    disp(' ');
%    disp('Row descriptives');
%    disp(' ');
%    PrintMasses(output.N',output.labels.r);
%    disp(' ');
%    disp(' ');
%    disp('Row profiles');
%    disp(' ');
%    CrossTabulateLabels(output.RP, output.labels.r, output.labels.c);
%    disp(' ');
%    disp(' ');
%    disp('-------------------------------------------------------------------------');
%    disp(' ');
%    disp(' ');
%    disp('Column descriptives');
%    disp(' ');
%    PrintMasses(output.N,output.labels.c);
%    disp(' ');
%    disp(' ');
%    disp('Column profiles');
%    disp(' ');
%    CrossTabulateLabels(output.CP, output.labels.r, output.labels.c);
%    disp(' ');
%    disp(' ');
%    %Matrix of standardized residuals
%    disp('-------------------------------------------------------------------------');
%    disp(' ');
%    disp(' ');
%    disp('Standardized residuals');
%    disp(' ');
%    CrossTabulateLabels(output.A, output.labels.r, output.labels.c);
%    disp(' ');
%    
% end;
% 
% disp('-------------------------------------------------------------------------');
% disp(' ');
% disp(' ');
% disp('Indices of association ');
% disp(' ');
% buff =sprintf('Dimensions    = %.0f',output.K);
% disp(buff);
% buff =sprintf('Chi-square    = %.5f',output.chis);
% disp(buff);
% buff =sprintf('Total inertia = %.5f',output.ti);
% disp(buff);
% buff =sprintf('Cramer`s V    = %.5f',output.CV);
% disp(buff);
% disp(' ');
% 
% disp('-------------------------------------------------------------------------');
% disp(' ');
% disp(' ');
% disp('Principal inertias (eigenvalues)');
% disp(' ');
% PrintPrincipalInertias(output.eig)
% disp(' ');
% disp(' ');
% buff=sprintf('Average explained variance: %6.1f%% (dimensions explaining less variance should be excluded from the map; equivalent to Kaiser''s One-eigenvalue rule in EFA)',output.aev);
% disp(buff);
% disp(' ');
% 
% if ParallelAnalysis == 1,
%     disp('-------------------------------------------------------------------------');
%     disp(' ');
%     disp('Parallel Analysis to determine the number of underlying dimensions (Lorenzo-Seva, 2011)');
%     disp(' ');
%     parallelCA(output.N,1,95);
%     disp(' ');
%     disp(' ');
% end;

return;